@@ -2,23 +2,20 @@
 #' @importFrom utils capture.output
 #' @keywords internal
 .cor_test_polychoric <- function(data, x, y, ci = 0.95, ...) {
-  if (!requireNamespace("psych", quietly = TRUE)) {
-    stop("Package `psych` required for tetrachoric correlations. Please install it by running `install.packages('psych').", call. = FALSE)
-  }
+  insight::check_if_installed("psych", "for 'tetrachronic' correlations")
 
   var_x <- .complete_variable_x(data, x, y)
   var_y <- .complete_variable_y(data, x, y)
 
-  # Sanity check
+  # valid matrix check
   if (!is.factor(var_x) & !is.factor(var_y)) {
     stop("Polychoric correlations can only be ran on ordinal factors.")
   }
 
 
   if (!is.factor(var_x) | !is.factor(var_y)) {
-    if (!requireNamespace("polycor", quietly = TRUE)) {
-      stop("Package `polycor` required for polyserial correlations. Please install it by running `install.packages('polycor').", call. = FALSE)
-    }
+    insight::check_if_installed("polycor", "for 'polyserial' correlations")
+
     r <- polycor::polyserial(
       x = if (is.factor(var_x)) as.numeric(var_y) else as.numeric(var_x),
       y = if (is.factor(var_x)) as.numeric(var_x) else as.numeric(var_y)
