@@ -11,7 +11,7 @@
 #'   can be a data frame and `select` and `select2` are (quoted) names
 #'   of variables (columns) in `data`. `correlation()` will then
 #'   compute the correlation between `data[select]` and
-#'   `data[select2]`. If only `select` is specified, all pair-wise
+#'   `data[select2]`. If only `select` is specified, all pairwise
 #'   correlations between the `select` variables will be computed. This is
 #'   a "pipe-friendly" alternative way of using `correlation()` (see
 #'   'Examples').
@@ -27,17 +27,20 @@
 #' @param redundant Should the data include redundant rows (where each given
 #'   correlation is repeated two times).
 #' @param verbose Toggle warnings.
-#' @param standardize_names This option can be set to `TRUE` to run [insight::standardize_names()] on the output to get standardized column names. This option can also be set globally by running `options(easystats.standardize_names = TRUE)`.
+#' @param standardize_names This option can be set to `TRUE` to run
+#'   [insight::standardize_names()] on the output to get standardized column
+#'   names. This option can also be set globally by running
+#'   `options(easystats.standardize_names = TRUE)`.
 #' @inheritParams cor_test
 #'
 #' @details
+#'
 #' \subsection{Correlation Types}{
-#' \itemize{
-#' \item **Pearson's correlation**: This is the most common correlation
+#' - **Pearson's correlation**: This is the most common correlation
 #' method. It corresponds to the covariance of the two variables normalized
 #' (i.e., divided) by the product of their standard deviations.
 #'
-#' \item **Spearman's rank correlation**: A non-parametric measure of rank
+#' - **Spearman's rank correlation**: A non-parametric measure of rank
 #' correlation (statistical dependence between the rankings of two variables).
 #' The Spearman correlation between two variables is equal to the Pearson
 #' correlation between the rank values of those two variables; while Pearson's
@@ -46,82 +49,82 @@
 #' for Spearman's correlations are computed using the Fieller et al. (1957)
 #' correction (see Bishara and Hittner, 2017).
 #'
-#' \item **Kendall's rank correlation**: In the normal case, the Kendall
-#' correlation is preferred than the Spearman correlation because of a smaller
-#' gross error sensitivity (GES) and a smaller asymptotic variance (AV), making
-#' it more robust and more efficient. However, the interpretation of Kendall's
-#' tau is less direct than that of Spearman's rho, in the sense that it
-#' quantifies the difference between the percentage of concordant and discordant pairs
-#' among all possible pairwise events. Confidence Intervals (CI) for Kendall's
+#' - **Kendall's rank correlation**: In the normal case, the Kendall correlation
+#' is preferred than the Spearman correlation because of a smaller gross error
+#' sensitivity (GES) and a smaller asymptotic variance (AV), making it more
+#' robust and more efficient. However, the interpretation of Kendall's tau is
+#' less direct than that of Spearman's rho, in the sense that it quantifies the
+#' difference between the percentage of concordant and discordant pairs among
+#' all possible pairwise events. Confidence Intervals (CI) for Kendall's
 #' correlations are computed using the Fieller et al. (1957) correction (see
 #' Bishara and Hittner, 2017).
 #'
-#' \item **Biweight midcorrelation**: A measure of similarity that is
+#' - **Biweight midcorrelation**: A measure of similarity that is
 #' median-based, instead of the traditional mean-based, thus being less
 #' sensitive to outliers. It can be used as a robust alternative to other
 #' similarity metrics, such as Pearson correlation (Langfelder & Horvath,
 #' 2012).
 #'
-#' \item **Distance correlation**: Distance correlation measures both
+#' - **Distance correlation**: Distance correlation measures both
 #' linear and non-linear association between two random variables or random
 #' vectors. This is in contrast to Pearson's correlation, which can only detect
 #' linear association between two random variables.
 #'
-#' \item **Percentage bend correlation**: Introduced by Wilcox (1994), it
+#' - **Percentage bend correlation**: Introduced by Wilcox (1994), it
 #' is based on a down-weight of a specified percentage of marginal observations
 #' deviating from the median (by default, `20%`).
 #'
-#' \item **Shepherd's Pi correlation**: Equivalent to a Spearman's rank
+#' - **Shepherd's Pi correlation**: Equivalent to a Spearman's rank
 #' correlation after outliers removal (by means of bootstrapped Mahalanobis
 #' distance).
 #'
-#' \item **Blomqvist’s coefficient**: The Blomqvist’s coefficient (also
+#' - **Blomqvist’s coefficient**: The Blomqvist’s coefficient (also
 #' referred to as Blomqvist's Beta or medial correlation; Blomqvist, 1950) is a
 #' median-based non-parametric correlation that has some advantages over
 #' measures such as Spearman's or Kendall's estimates (see Shmid & Schimdt,
 #' 2006).
 #'
-#' \item **Hoeffding’s D**: The Hoeffding’s D statistics is a
+#' - **Hoeffding’s D**: The Hoeffding’s D statistics is a
 #' non-parametric rank based measure of association that detects more general
 #' departures from independence (Hoeffding 1948), including non-linear
 #' associations. Hoeffding’s D varies between -0.5 and 1 (if there are no tied
 #' ranks, otherwise it can have lower values), with larger values indicating a
 #' stronger relationship between the variables.
 #'
-#' \item **Somers’ D**: The Somers’ D statistics is a non-parametric rank
+#' - **Somers’ D**: The Somers’ D statistics is a non-parametric rank
 #' based measure of association between a binary variable and a continuous
 #' variable, for instance, in the context of logistic regression the binary
 #' outcome and the predicted probabilities for each outcome. Usually, Somers' D
 #' is a measure of ordinal association, however, this implementation it is
 #' limited to the case of a binary outcome.
 #'
-#' \item **Point-Biserial and biserial correlation**: Correlation
+#' - **Point-Biserial and biserial correlation**: Correlation
 #' coefficient used when one variable is continuous and the other is dichotomous
 #' (binary). Point-Biserial is equivalent to a Pearson's correlation, while
 #' Biserial should be used when the binary variable is assumed to have an
 #' underlying continuity. For example, anxiety level can be measured on a
 #' continuous scale, but can be classified dichotomously as high/low.
 #'
-#' \item **Gamma correlation**: The Goodman-Kruskal gamma statistic is
+#' - **Gamma correlation**: The Goodman-Kruskal gamma statistic is
 #' similar to Kendall's Tau coefficient. It is relatively robust to outliers and
 #' deals well with data that have many ties.
 #'
-#' \item **Winsorized correlation**: Correlation of variables that have
+#' - **Winsorized correlation**: Correlation of variables that have
 #' been formerly Winsorized, i.e., transformed by limiting extreme values to
 #' reduce the effect of possibly spurious outliers.
 #'
-#' \item **Gaussian rank Correlation**: The Gaussian rank correlation
+#' - **Gaussian rank Correlation**: The Gaussian rank correlation
 #' estimator is a simple and well-performing alternative for robust rank
 #' correlations (Boudt et al., 2012). It is based on the Gaussian quantiles of
 #' the ranks.
 #'
-#' \item **Polychoric correlation**: Correlation between two theorized
+#' - **Polychoric correlation**: Correlation between two theorized
 #' normally distributed continuous latent variables, from two observed ordinal
 #' variables.
 #'
-#' \item **Tetrachoric correlation**: Special case of the polychoric
+#' - **Tetrachoric correlation**: Special case of the polychoric
 #' correlation applicable when both observed variables are dichotomous.
-#' }}
+#' }
 #'
 #' \subsection{Partial Correlation}{
 #' **Partial correlations** are estimated as the correlation between two
@@ -139,33 +142,33 @@
 #' variables depicted as circles ("nodes"), and a set of lines that visualize
 #' relationships between them, which thickness represents the strength of
 #' association (see Bhushan et al., 2019).
-#' \cr\cr
-#' **Multilevel correlations** are a special case of partial correlations
-#' where the variable to be adjusted for is a factor and is included as a random
+#'
+#' **Multilevel correlations** are a special case of partial correlations where
+#' the variable to be adjusted for is a factor and is included as a random
 #' effect in a mixed model (note that the remaining continuous variables of the
 #' dataset will still be included as fixed effects, similarly to regular partial
 #' correlations). That said, there is an important difference between using
-#' `cor_test()` and `correlation()`: If you set `multilevel=TRUE`
-#' in `correlation()` but `partial` is set to `FALSE` (as per
-#' default), then a back-transformation from partial to non-partial correlation
-#' will be attempted (through [`pcor_to_cor()`][pcor_to_cor]). However,
-#' this is not possible when using `cor_test()` so that if you set
-#' `multilevel=TRUE` in it, the resulting correlations are partial one.
-#' Note that for Bayesian multilevel correlations, if `partial = FALSE`,
-#' the back transformation will also recompute p-values based on the new r scores,
-#' and will drop the Bayes factors (as they are not relevant anymore). To keep
-#' Bayesian scores, don't forget to set `partial = TRUE`.
+#' `cor_test()` and `correlation()`: If you set `multilevel=TRUE` in
+#' `correlation()` but `partial` is set to `FALSE` (as per default), then a
+#' back-transformation from partial to non-partial correlation will be attempted
+#' (through [`pcor_to_cor()`][pcor_to_cor]). However, this is not possible when
+#' using `cor_test()` so that if you set `multilevel=TRUE` in it, the resulting
+#' correlations are partial one. Note that for Bayesian multilevel correlations,
+#' if `partial = FALSE`, the back transformation will also recompute *p*-values
+#' based on the new *r* scores, and will drop the Bayes factors (as they are not
+#' relevant anymore). To keep Bayesian scores, set `partial = TRUE`.
 #' }
 #'
 #' \subsection{Notes}{
-#' \itemize{
-#'   \item Kendall and Spearman correlations when `bayesian=TRUE`: These
-#'   are technically Pearson Bayesian correlations of rank transformed data,
-#'   rather than pure Bayesian rank correlations (which have different priors).
-#' }}
+#' Kendall and Spearman correlations when `bayesian=TRUE`: These are technically
+#' Pearson Bayesian correlations of rank transformed data, rather than pure
+#' Bayesian rank correlations (which have different priors).
+#' }
 #'
-#' @return A correlation object that can be displayed using the `print`,
-#'   `summary` or `table` methods.
+#' @return
+#'
+#' A correlation object that can be displayed using the `print`, `summary` or
+#' `table` methods.
 #'
 #' \subsection{Multiple tests correction}{
 #' The `p_adjust` argument can be used to adjust p-values for multiple
@@ -174,6 +177,7 @@
 #' }
 #'
 #' @examples
+#'
 #' library(correlation)
 #' results <- correlation(iris)
 #'
@@ -181,8 +185,8 @@
 #' summary(results)
 #' summary(results, redundant = TRUE)
 #'
-#' # pipe-friendly usage
-#' if (require("dplyr")) {
+#' # pipe-friendly usage with  grouped dataframes from {dplyr} package
+#' if (require("poorman")) {
 #'   iris %>%
 #'     correlation(select = "Petal.Width", select2 = "Sepal.Length")
 #'
@@ -209,33 +213,32 @@
 #'
 #' @references
 #'
-#' \itemize{
-#'   \item Boudt, K., Cornelissen, J., & Croux, C. (2012). The Gaussian rank
+#' - Boudt, K., Cornelissen, J., & Croux, C. (2012). The Gaussian rank
 #'   correlation estimator: robustness properties. Statistics and Computing,
 #'   22(2), 471-483.
 #'
-#'   \item Bhushan, N., Mohnert, F., Sloot, D., Jans, L., Albers, C., & Steg, L.
+#' - Bhushan, N., Mohnert, F., Sloot, D., Jans, L., Albers, C., & Steg, L.
 #'   (2019). Using a Gaussian graphical model to explore relationships between
 #'   items and variables in environmental psychology research. Frontiers in
 #'   psychology, 10, 1050.
 #'
-#'   \item Bishara, A. J., & Hittner, J. B. (2017). Confidence intervals for
+#' - Bishara, A. J., & Hittner, J. B. (2017). Confidence intervals for
 #'   correlations when data are not normal. Behavior research methods, 49(1),
 #'   294-309.
 #'
-#'   \item Fieller, E. C., Hartley, H. O., & Pearson, E. S. (1957). Tests for
+#' - Fieller, E. C., Hartley, H. O., & Pearson, E. S. (1957). Tests for
 #'   rank correlation coefficients. I. Biometrika, 44(3/4), 470-481.
 #'
-#'   \item Langfelder, P., & Horvath, S. (2012). Fast R functions for robust
+#' - Langfelder, P., & Horvath, S. (2012). Fast R functions for robust
 #'   correlations and hierarchical clustering. Journal of statistical software,
 #'   46(11).
 #'
-#'   \item Blomqvist, N. (1950). On a measure of dependence between two random
+#' - Blomqvist, N. (1950). On a measure of dependence between two random
 #'   variables,Annals of Mathematical Statistics,21, 593–600
 #'
-#'   \item Somers, R. H. (1962). A new asymmetric measure of association for
+#' - Somers, R. H. (1962). A new asymmetric measure of association for
 #'   ordinal variables. American Sociological Review. 27 (6).
-#' }
+#'
 #' @export
 correlation <- function(data,
                         data2 = NULL,
@@ -255,18 +258,11 @@ correlation <- function(data,
                         partial_bayesian = FALSE,
                         multilevel = FALSE,
                         ranktransform = FALSE,
-                        robust = NULL,
                         winsorize = FALSE,
                         verbose = TRUE,
                         standardize_names = getOption("easystats.standardize_names", FALSE),
                         ...) {
 
-  # Deprecation warnings
-  if (!is.null(robust)) {
-    warning("The 'robust' argument is deprecated in favour of 'ranktransform' (more explicit). Please use the latter instead to remove this warning.")
-    ranktransform <- robust
-  }
-
   # valid matrix checks
   if (partial == FALSE & multilevel) {
     partial <- TRUE
