@@ -13,7 +13,7 @@ print.easycorrelation <- function(x, ...) {
 print.easycormatrix <- function(x, ...) {
   formatted <- format(x, ...)
   # If real matrix, print as matrix
-  if(colnames(formatted)[1] == "Variables") {
+  if (colnames(formatted)[1] == "Variables") {
     formatted$Variables <- NULL
     print(as.matrix(formatted))
   } else {
@@ -178,17 +178,3 @@ print_html.easycormatrix <- function(x,
     ...
   )
 }
-
-
-
-
-# Reexports functions ------------------------
-
-#' @importFrom insight print_md
-#' @export
-insight::print_md
-
-
-#' @importFrom insight print_html
-#' @export
-insight::print_html
